@@ -39,24 +39,8 @@ extern struct fsck_agg_record *agg_recptr;
   *
   *      defined in xchkdsk.c
   */
-extern char message_parm_0[];
-extern char message_parm_1[];
-extern char message_parm_2[];
-extern char message_parm_3[];
-extern char message_parm_4[];
-extern char message_parm_5[];
-extern char message_parm_6[];
-extern char message_parm_7[];
-extern char message_parm_8[];
-extern char message_parm_9[];
-
-extern char *msgprms[];
-extern int16_t msgprmidx[];
-
 extern char *verbose_msg_ptr;
 
-extern char *MsgText[];
-
 extern char *Vol_Label;
 
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
@@ -124,19 +108,7 @@ int adjust_parent(uint32_t child_ino, struct fsck_inode_record *child_inorecptr,
 
 	if ((adjp_rc == FSCK_OK) && (parent_inorecptr == NULL)) {
 		adjp_rc = FSCK_INTERNAL_ERROR_4;
-		sprintf(message_parm_0, "%d", adjp_rc);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		sprintf(message_parm_1, "%d", child_ino);
-		msgprms[1] = message_parm_1;
-		msgprmidx[1] = 0;
-		sprintf(message_parm_2, "%d", parent_ino);
-		msgprms[2] = message_parm_2;
-		msgprmidx[2] = 0;
-		sprintf(message_parm_3, "%d", 0);
-		msgprms[3] = message_parm_3;
-		msgprmidx[3] = 0;
-		fsck_send_msg(fsck_INTERNALERROR, 4);
+		fsck_send_msg(fsck_INTERNALERROR, adjp_rc, child_ino, parent_ino, 0);
 
 	} else if (adjp_rc == FSCK_OK) {
 		/* located the parent's inode record */
@@ -352,13 +324,9 @@ int check_connectedness()
 
 			if (this_inorec->parent_inonum == 0) {
 				/* no parents were observed by fsck */
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = msg_info_ptr->msg_inopfx;
-				sprintf(message_parm_1, "%d",
-					msg_info_ptr->msg_inonum);
-				msgprms[1] = message_parm_1;
-				msgprmidx[1] = 0;
-				fsck_send_msg(fsck_INONOPATHS, 2);
+				fsck_send_msg(fsck_INONOPATHS,
+					      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+					      msg_info_ptr->msg_inonum);
 			} else {
 				/* at least one parent observed by fsck */
 				/*
@@ -415,23 +383,10 @@ int check_connectedness()
 								    adjust_parents
 								    (this_inorec,
 								     ino_idx);
-								msgprms[0] =
-								    message_parm_0;
-								msgprmidx[0] =
-								    msg_info_ptr->
-								    msg_inopfx;
-								sprintf
-								    (message_parm_1,
-								     "%d",
-								     msg_info_ptr->
-								     msg_inonum);
-								msgprms[1] =
-								    message_parm_1;
-								msgprmidx[1] =
-								    0;
 								fsck_send_msg
 								    (fsck_WILLFIXDIRWHDLKS,
-								     2);
+								     fsck_ref_msg(msg_info_ptr->msg_inopfx),
+								     msg_info_ptr->msg_inonum);
 
 							} else {
 								/* no write access */
@@ -441,23 +396,10 @@ int check_connectedness()
 								agg_recptr->
 								    ag_dirty =
 								    1;
-								msgprms[0] =
-								    message_parm_0;
-								msgprmidx[0] =
-								    msg_info_ptr->
-								    msg_inopfx;
-								sprintf
-								    (message_parm_1,
-								     "%d",
-								     msg_info_ptr->
-								     msg_inonum);
-								msgprms[1] =
-								    message_parm_1;
-								msgprmidx[1] =
-								    0;
 								fsck_send_msg
 								    (fsck_DIRWHDLKS,
-								     2);
+								     fsck_ref_msg(msg_info_ptr->msg_inopfx),
+								     msg_info_ptr->msg_inonum);
 							}
 						}
 					} else if ((cc_rc == FSCK_OK)
@@ -474,21 +416,10 @@ int check_connectedness()
 
 						if (agg_recptr->
 						    processing_readwrite) {
-							msgprms[0] =
-							    message_parm_0;
-							msgprmidx[0] =
-							    msg_info_ptr->
-							    msg_inopfx;
-							sprintf(message_parm_1,
-								"%d",
-								msg_info_ptr->
-								msg_inonum);
-							msgprms[1] =
-							    message_parm_1;
-							msgprmidx[1] = 0;
 							fsck_send_msg
 							    (fsck_WILLFIXINCREF,
-							     2);
+							     fsck_ref_msg(msg_info_ptr->msg_inopfx),
+							     msg_info_ptr->msg_inonum);
 						} else {
 							/* no write access */
 							this_inorec->
@@ -496,20 +427,10 @@ int check_connectedness()
 							    0;
 							agg_recptr->ag_dirty =
 							    1;
-							msgprms[0] =
-							    message_parm_0;
-							msgprmidx[0] =
-							    msg_info_ptr->
-							    msg_inopfx;
-							sprintf(message_parm_1,
-								"%d",
-								msg_info_ptr->
-								msg_inonum);
-							msgprms[1] =
-							    message_parm_1;
-							msgprmidx[1] = 0;
 							fsck_send_msg
-							    (fsck_INCINOREF, 2);
+							    (fsck_INCINOREF,
+							     fsck_ref_msg(msg_info_ptr->msg_inopfx),
+							     msg_info_ptr->msg_inonum);
 						}
 					}
 				}
@@ -644,49 +565,12 @@ int check_dir_integrity()
 									/*
 									 * notify the user that the directory is bad
 									 */
-									msgprms
-									    [0]
-									    =
-									    message_parm_0;
-									msgprmidx
-									    [0]
-									    =
-									    fsck_directory;
-									msgprms
-									    [1]
-									    =
-									    message_parm_1;
-									msgprmidx
-									    [1]
-									    =
-									    msg_info_ptr->
-									    msg_inopfx;
-									sprintf
-									    (message_parm_2,
-									     "%d",
-									     this_ext->
-									     inonum);
-									msgprms
-									    [2]
-									    =
-									    message_parm_2;
-									msgprmidx
-									    [2]
-									    = 0;
-									sprintf
-									    (message_parm_3,
-									     "%d",
-									     37);
-									msgprms
-									    [3]
-									    =
-									    message_parm_3;
-									msgprmidx
-									    [3]
-									    = 0;
 									fsck_send_msg
 									    (fsck_BADKEYS,
-									     4);
+									     fsck_ref_msg(fsck_directory),
+									     fsck_ref_msg(msg_info_ptr->msg_inopfx),
+									     this_ext->inonum,
+									     37);
 								}
 							}
 						}
@@ -777,20 +661,8 @@ int check_link_counts()
 				if ((clc_rc != FSCK_OK)
 				    || (parent_inorec == NULL)) {
 					clc_rc = FSCK_INTERNAL_ERROR_13;
-					sprintf(message_parm_0, "%d", clc_rc);
-					msgprms[0] = message_parm_0;
-					msgprmidx[0] = 0;
-					sprintf(message_parm_1, "%d", ino_idx);
-					msgprms[1] = message_parm_1;
-					msgprmidx[1] = 0;
-					sprintf(message_parm_2, "%d",
-						this_inorec->parent_inonum);
-					msgprms[2] = message_parm_2;
-					msgprmidx[2] = 0;
-					sprintf(message_parm_3, "%d", 0);
-					msgprms[3] = message_parm_3;
-					msgprmidx[3] = 0;
-					fsck_send_msg(fsck_INTERNALERROR, 4);
+					fsck_send_msg(fsck_INTERNALERROR, clc_rc, ino_idx,
+						      this_inorec->parent_inonum, 0);
 				} else {
 					/* handle the first (and usually the only) parent. */
 					parent_inorec->link_count++;
@@ -859,58 +731,12 @@ int check_link_counts()
 										clc_rc
 										    =
 										    FSCK_INTERNAL_ERROR_14;
-										sprintf
-										    (message_parm_0,
-										     "%d",
-										     clc_rc);
-										msgprms
-										    [0]
-										    =
-										    message_parm_0;
-										msgprmidx
-										    [0]
-										    =
-										    0;
-										sprintf
-										    (message_parm_1,
-										     "%d",
-										     ino_idx);
-										msgprms
-										    [1]
-										    =
-										    message_parm_1;
-										msgprmidx
-										    [1]
-										    =
-										    0;
-										sprintf
-										    (message_parm_2,
-										     "%d",
-										     this_ext->
-										     inonum);
-										msgprms
-										    [2]
-										    =
-										    message_parm_2;
-										msgprmidx
-										    [2]
-										    =
-										    0;
-										sprintf
-										    (message_parm_3,
-										     "%d",
-										     0);
-										msgprms
-										    [3]
-										    =
-										    message_parm_3;
-										msgprmidx
-										    [3]
-										    =
-										    0;
 										fsck_send_msg
 										    (fsck_INTERNALERROR,
-										     4);
+										     clc_rc,
+										     ino_idx,
+										     this_ext->inonum,
+										     0);
 									} else {
 										parent_inorec->
 										    link_count++;
@@ -966,15 +792,9 @@ int check_link_counts()
 						}
 						invalid_count_seen = 1;
 
-						msgprms[0] = message_parm_0;
-						msgprmidx[0] =
-						    msg_info_ptr->msg_inopfx;
-						sprintf(message_parm_1, "%d",
-							ino_idx);
-						msgprms[1] = message_parm_1;
-						msgprmidx[1] = 0;
 						fsck_send_msg(fsck_BADINOLKCT,
-							      2);
+							      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+							      ino_idx);
 					}
 				}
 			}
@@ -989,7 +809,7 @@ int check_link_counts()
 
 			if (agg_recptr->processing_readwrite) {
 				agg_recptr->corrections_approved = 1;
-				fsck_send_msg(fsck_WILLFIXLINKCTS, 0);
+				fsck_send_msg(fsck_WILLFIXLINKCTS);
 			} else {
 				/* no write access */
 				if (low_stored_count_seen) {
@@ -1022,7 +842,7 @@ int check_link_counts()
 							       &ino_idx,
 							       &this_inorec);
 				}
-				fsck_send_msg(fsck_BADLINKCTS, 0);
+				fsck_send_msg(fsck_BADLINKCTS);
 			}
 		}
 	}
@@ -1077,20 +897,9 @@ int reset_parents(struct fsck_inode_record *ino_recptr, uint32_t ino_idx)
 					 &parent_inorecptr);
 		if ((resps_rc == FSCK_OK) && (parent_inorecptr == NULL)) {
 			resps_rc = FSCK_INTERNAL_ERROR_15;
-			sprintf(message_parm_0, "%d", resps_rc);
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = 0;
-			sprintf(message_parm_1, "%d", ino_idx);
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = 0;
-			sprintf(message_parm_2, "%d",
-				ino_recptr->parent_inonum);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			sprintf(message_parm_3, "%d", 0);
-			msgprms[3] = message_parm_3;
-			msgprmidx[3] = 0;
-			fsck_send_msg(fsck_INTERNALERROR, 4);
+			fsck_send_msg(fsck_INTERNALERROR, resps_rc, ino_idx,
+				      ino_recptr->parent_inonum,
+				      0);
 
 		} else if (resps_rc == FSCK_OK) {
 			if ((ino_recptr->parent_inonum == ROOT_I)
@@ -1135,19 +944,8 @@ int reset_parents(struct fsck_inode_record *ino_recptr, uint32_t ino_idx)
 						 &parent_inorecptr);
 			if ((resps_rc == FSCK_OK) && (parent_inorecptr == NULL)) {
 				resps_rc = FSCK_INTERNAL_ERROR_16;
-				sprintf(message_parm_0, "%d", resps_rc);
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = 0;
-				sprintf(message_parm_1, "%d", ino_idx);
-				msgprms[1] = message_parm_1;
-				msgprmidx[1] = 0;
-				sprintf(message_parm_2, "%d", this_ext->inonum);
-				msgprms[2] = message_parm_2;
-				msgprmidx[2] = 0;
-				sprintf(message_parm_3, "%d", 0);
-				msgprms[3] = message_parm_3;
-				msgprmidx[3] = 0;
-				fsck_send_msg(fsck_INTERNALERROR, 4);
+				fsck_send_msg(fsck_INTERNALERROR, resps_rc, ino_idx,
+					      this_ext->inonum, 0);
 
 			} else if (resps_rc == FSCK_OK) {
 				if ((ino_recptr->parent_inonum == ROOT_I)
