@@ -102,7 +102,7 @@ struct btstack {
 	(BP->flag & BT_ROOT) ? (TYPE *)&IP->di_btroot : (TYPE *)BP
 
 /* get the page buffer and the page for specified block address */
-#define FSCK_BT_GETPAGE(IP, BN, BP, TYPE, SIZE, P, RC)\
+#define FSCK_BT_GETPAGE(IP, BN, BP, TYPE, P, RC)\
 {\
 	if ((BN) == 0)\
 	{\
@@ -201,7 +201,6 @@ int fsck_dtSearch(struct dinode *ip,
 	int32_t base, index, lim;
 	struct btframe *btsp;
 	pxd_t *pxd;
-	int32_t psize = 288;	/* initial in-line directory */
 	uint32_t inumber;
 	UniChar ciKeyName[JFS_NAME_MAX + 1];
 	struct component_name ciKey = { 0, ciKeyName };
@@ -239,7 +238,7 @@ int fsck_dtSearch(struct dinode *ip,
 	 */
 	for (bn = 0;;) {
 		/* get/pin the page to search */
-		FSCK_BT_GETPAGE(ip, bn, bp, dtpage_t, psize, p, rc);
+		FSCK_BT_GETPAGE(ip, bn, bp, dtpage_t, p, rc);
 		if (rc)
 			return rc;
 
@@ -371,7 +370,6 @@ int fsck_dtSearch(struct dinode *ip,
 		/* get the child page block number */
 		pxd = (pxd_t *) & p->slot[stbl[index]];
 		bn = addressPXD(pxd);
-		psize = lengthPXD(pxd) << agg_recptr->log2_blksize;
 
 		/* unpin the parent page */
 		FSCK_BT_PUTPAGE(bp);
@@ -607,7 +605,7 @@ static int dtSplitUp(struct dinode *ip, struct dtsplit *split,
 		 *
 		 * get the parent page <sp> 
 		 */
-		FSCK_BT_GETPAGE(ip, parent->bn, sbp, dtpage_t, PSIZE, sp, rc);
+		FSCK_BT_GETPAGE(ip, parent->bn, sbp, dtpage_t, sp, rc);
 		if (rc) {
 			FSCK_BT_PUTPAGE(lbp);
 			FSCK_BT_PUTPAGE(rbp);
@@ -860,7 +858,7 @@ static int dtSplitPage(struct dinode *ip, struct dtsplit *split,
 	 *  update prev pointer of previous right sibling page;
 	 */
 	if (nextbn != 0) {
-		FSCK_BT_GETPAGE(ip, nextbn, bp, dtpage_t, PSIZE, p, rc);
+		FSCK_BT_GETPAGE(ip, nextbn, bp, dtpage_t, p, rc);
 		if (rc) {
 			recon_dnode_release((dtpage_t *) rbp);
 			return rc;
@@ -989,7 +987,6 @@ static int dtSplitPage(struct dinode *ip, struct dtsplit *split,
 static int dtSplitRoot(struct dinode *ip, struct dtsplit *split,
 		       struct btpage **rbpp)
 {
-	struct btpage *sbp;
 	dtroot_t *sp;
 	struct btpage *rbp;
 	dtpage_t *rp;
@@ -1005,7 +1002,6 @@ static int dtSplitRoot(struct dinode *ip, struct dtsplit *split,
 	pxd_t *pxd;
 
 	/* get split root page */
-	sbp = split->bp;
 	sp = (dtroot_t *) & ip->di_btroot;
 
 	/*
@@ -1250,7 +1246,7 @@ static int fsck_dtDeleteUp(struct dinode *ip, struct btpage *fbp,
 	 */
 	while ((parent = BT_POP(btstack)) != NULL) {
 		/* pin the parent page <sp> */
-		FSCK_BT_GETPAGE(ip, parent->bn, bp, dtpage_t, PSIZE, p, rc);
+		FSCK_BT_GETPAGE(ip, parent->bn, bp, dtpage_t, p, rc);
 		if (rc)
 			return rc;
 
@@ -1349,7 +1345,7 @@ static int dtRelink(struct dinode *ip, dtpage_t * p)
 
 	/* update prev pointer of the next page */
 	if (nextbn != 0) {
-		FSCK_BT_GETPAGE(ip, nextbn, bp, dtpage_t, PSIZE, p, rc);
+		FSCK_BT_GETPAGE(ip, nextbn, bp, dtpage_t, p, rc);
 		if (rc)
 			return rc;
 
@@ -1359,7 +1355,7 @@ static int dtRelink(struct dinode *ip, dtpage_t * p)
 
 	/* update next pointer of the previous page */
 	if (prevbn != 0) {
-		FSCK_BT_GETPAGE(ip, prevbn, bp, dtpage_t, PSIZE, p, rc);
+		FSCK_BT_GETPAGE(ip, prevbn, bp, dtpage_t, p, rc);
 		if (rc)
 			return rc;
 
