@@ -41,24 +41,8 @@ extern struct fsck_agg_record *agg_recptr;
   *
   *      defined in xchkdsk.c
   */
-extern char message_parm_0[];
-extern char message_parm_1[];
-extern char message_parm_2[];
-extern char message_parm_3[];
-extern char message_parm_4[];
-extern char message_parm_5[];
-extern char message_parm_6[];
-extern char message_parm_7[];
-extern char message_parm_8[];
-extern char message_parm_9[];
-
-extern char *msgprms[];
-extern int16_t msgprmidx[];
-
 extern char *verbose_msg_ptr;
 
-extern char *MsgText[];
-
 extern char *Vol_Label;
 
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
@@ -481,17 +465,11 @@ int xTree_node_first_key(struct fsck_Xtree_info *xtiptr,
 		inorecptr->ignore_alloc_blks = 1;
 		if (desired_action == FSCK_RECORD_DUPCHECK) {
 			/* not reported yet */
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = msg_info_ptr->msg_inotyp;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			sprintf(message_parm_3, "%d", 5);
-			msgprms[3] = message_parm_3;
-			msgprmidx[3] = 0;
-			fsck_send_msg(fsck_BADKEYS, 4);
+			fsck_send_msg(fsck_BADKEYS,
+				      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+				      msg_info_ptr->msg_inonum,
+				      5);
 		}
 		goto out;
 	}
@@ -508,17 +486,10 @@ int xTree_node_first_key(struct fsck_Xtree_info *xtiptr,
 			inorecptr->ignore_alloc_blks = 1;
 			if (desired_action == FSCK_RECORD_DUPCHECK) {
 				/* not reported yet */
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = msg_info_ptr->msg_inopfx;
-				sprintf(message_parm_1, "%d",
-					msg_info_ptr->msg_inonum);
-				msgprms[1] = message_parm_1;
-				msgprmidx[1] = 0;
-				sprintf(message_parm_2, "%lld",
-					(long long) xtiptr->last_key);
-				msgprms[2] = message_parm_2;
-				msgprmidx[2] = 0;
-				fsck_send_msg(fsck_BADINOINTERNGAP, 3);
+				fsck_send_msg(fsck_BADINOINTERNGAP,
+					      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+					      msg_info_ptr->msg_inonum,
+					      (long long) xtiptr->last_key);
 			}
 		}
 	} else {
@@ -528,18 +499,10 @@ int xTree_node_first_key(struct fsck_Xtree_info *xtiptr,
 			inorecptr->ignore_alloc_blks = 1;
 			if (desired_action == FSCK_RECORD_DUPCHECK) {
 				/* not reported yet */
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = msg_info_ptr->msg_inotyp;
-				msgprms[1] = message_parm_1;
-				msgprmidx[1] = msg_info_ptr->msg_inopfx;
-				sprintf(message_parm_2, "%d",
-					msg_info_ptr->msg_inonum);
-				msgprms[2] = message_parm_2;
-				msgprmidx[2] = 0;
-				sprintf(message_parm_3, "%d", 6);
-				msgprms[3] = message_parm_3;
-				msgprmidx[3] = 0;
-				fsck_send_msg(fsck_BADKEYS, 4);
+				fsck_send_msg(fsck_BADKEYS,
+					      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+					      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+					      msg_info_ptr->msg_inonum, 6);
 			}
 		}
 	}
@@ -580,14 +543,10 @@ int xTree_node_first_in_level(struct fsck_Xtree_info *xtiptr,
 
 		if (desired_action == FSCK_RECORD_DUPCHECK) {
 			/* not reported yet */
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = msg_info_ptr->msg_inotyp;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			fsck_send_msg(fsck_BADBSBLCHN, 3);
+			fsck_send_msg(fsck_BADBSBLCHN,
+				      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+				      msg_info_ptr->msg_inonum);
 		}
 	}
 	return (xnfil_rc);
@@ -624,14 +583,10 @@ int xTree_node_last_in_level(struct fsck_Xtree_info *xtiptr,
 		inorecptr->ignore_alloc_blks = 1;
 		if (desired_action == FSCK_RECORD_DUPCHECK) {
 			/* not reported yet */
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = msg_info_ptr->msg_inotyp;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			fsck_send_msg(fsck_BADFSBLCHN, 3);
+			fsck_send_msg(fsck_BADFSBLCHN,
+				      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+				      msg_info_ptr->msg_inonum);
 		}
 	}
 	return (xnlil_rc);
@@ -669,14 +624,10 @@ int xTree_node_not_first_in_level(struct fsck_Xtree_info *xtiptr,
 
 		if (desired_action == FSCK_RECORD_DUPCHECK) {
 			/* not reported yet */
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = msg_info_ptr->msg_inotyp;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			fsck_send_msg(fsck_BADBSBLCHN, 3);
+			fsck_send_msg(fsck_BADBSBLCHN,
+				      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+				      msg_info_ptr->msg_inonum);
 		}
 	}
 	return (xnnfil_rc);
@@ -713,14 +664,10 @@ int xTree_node_not_last_in_level(struct fsck_Xtree_info *xtiptr,
 		inorecptr->ignore_alloc_blks = 1;
 		if (desired_action == FSCK_RECORD_DUPCHECK) {
 			/* not reported yet */
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = msg_info_ptr->msg_inotyp;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			fsck_send_msg(fsck_BADFSBLCHN, 3);
+			fsck_send_msg(fsck_BADFSBLCHN,
+				      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+				      msg_info_ptr->msg_inonum);
 		}
 	} else {
 		/* forward sibling pointer is correct */
@@ -739,23 +686,12 @@ int xTree_node_not_last_in_level(struct fsck_Xtree_info *xtiptr,
 						   nextindex - 1]);
 				xtiptr->this_key = offsetXAD(xtiptr->xad_ptr);
 				xtiptr->ext_length = lengthXAD(xtiptr->xad_ptr);
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = msg_info_ptr->msg_inotyp;
-				msgprms[1] = message_parm_1;
-				msgprmidx[1] = msg_info_ptr->msg_inopfx;
-				sprintf(message_parm_2, "%d",
-					msg_info_ptr->msg_inonum);
-				msgprms[2] = message_parm_2;
-				msgprmidx[2] = 0;
-				sprintf(message_parm_3, "%lld",
-					(long long) xtiptr->this_key);
-				msgprms[3] = message_parm_3;
-				msgprmidx[3] = 0;
-				sprintf(message_parm_4, "%d",
-					xtiptr->ext_length);
-				msgprms[4] = message_parm_4;
-				msgprmidx[4] = 0;
-				fsck_send_msg(fsck_BADINOODDINTRNEXT, 5);
+				fsck_send_msg(fsck_BADINOODDINTRNEXT,
+					      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+					      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+					      msg_info_ptr->msg_inonum,
+					      (long long) xtiptr->this_key,
+					      xtiptr->ext_length);
 			}
 		}
 	}
@@ -826,18 +762,11 @@ int xTree_process_internal_extents(xtpage_t * xtpg_ptr,
 			ino_recptr->ignore_alloc_blks = 1;
 			if (desired_action == FSCK_RECORD_DUPCHECK) {
 				/* first detection */
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = msg_info_ptr->msg_inotyp;
-				msgprms[1] = message_parm_1;
-				msgprmidx[1] = msg_info_ptr->msg_inopfx;
-				sprintf(message_parm_2, "%d",
-					msg_info_ptr->msg_inonum);
-				msgprms[2] = message_parm_2;
-				msgprmidx[2] = 0;
-				sprintf(message_parm_3, "%d", 7);
-				msgprms[3] = message_parm_3;
-				msgprmidx[3] = 0;
-				fsck_send_msg(fsck_BADKEYS, 4);
+				fsck_send_msg(fsck_BADKEYS,
+					      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+					      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+					      msg_info_ptr->msg_inonum,
+					      7);
 			}
 			goto out;
 		}
@@ -947,18 +876,11 @@ int xTree_process_leaf_extents(xtpage_t * xtpg_ptr,
 				ino_recptr->ignore_alloc_blks = 1;
 				if (desired_action == FSCK_RECORD_DUPCHECK) {
 					/* first detection */
-					msgprms[0] = message_parm_0;
-					msgprmidx[0] = msg_info_ptr->msg_inotyp;
-					msgprms[1] = message_parm_1;
-					msgprmidx[1] = msg_info_ptr->msg_inopfx;
-					sprintf(message_parm_2, "%d",
-						msg_info_ptr->msg_inonum);
-					msgprms[2] = message_parm_2;
-					msgprmidx[2] = 0;
-					sprintf(message_parm_3, "%d", 8);
-					msgprms[3] = message_parm_3;
-					msgprmidx[3] = 0;
-					fsck_send_msg(fsck_BADKEYS, 4);
+					fsck_send_msg(fsck_BADKEYS,
+						      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+						      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+						      msg_info_ptr->msg_inonum,
+						      8);
 				}
 				goto out;
 			}
@@ -969,17 +891,10 @@ int xTree_process_leaf_extents(xtpage_t * xtpg_ptr,
 				ino_recptr->ignore_alloc_blks = 1;
 				if (desired_action == FSCK_RECORD_DUPCHECK) {
 					/* first detection */
-					msgprms[0] = message_parm_0;
-					msgprmidx[0] = msg_info_ptr->msg_inopfx;
-					sprintf(message_parm_1, "%d",
-						msg_info_ptr->msg_inonum);
-					msgprms[1] = message_parm_1;
-					msgprmidx[1] = 0;
-					sprintf(message_parm_2, "%d",
-						msg_info_ptr->msg_inonum);
-					msgprms[2] = message_parm_2;
-					msgprmidx[2] = 0;
-					fsck_send_msg(fsck_BADINOINTERNGAP, 3);
+					fsck_send_msg(fsck_BADINOINTERNGAP,
+						      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+						      msg_info_ptr->msg_inonum,
+						      msg_info_ptr->msg_inonum);
 				}
 				goto out;
 			}
@@ -1012,24 +927,13 @@ int xTree_process_leaf_extents(xtpage_t * xtpg_ptr,
 				ino_recptr->ignore_alloc_blks = 1;
 				if (desired_action == FSCK_RECORD_DUPCHECK) {
 					/* first detection */
-					msgprms[0] = message_parm_0;
-					msgprmidx[0] = msg_info_ptr->msg_inotyp;
-					msgprms[1] = message_parm_1;
-					msgprmidx[1] = msg_info_ptr->msg_inopfx;
-					sprintf(message_parm_2, "%d",
-						msg_info_ptr->msg_inonum);
-					msgprms[2] = message_parm_2;
-					msgprmidx[2] = 0;
-					sprintf(message_parm_3, "%lld",
-						(long long) this_key);
-					msgprms[3] = message_parm_3;
-					msgprmidx[3] = 0;
-					sprintf(message_parm_4, "%d",
-						ext_length);
-					msgprms[4] = message_parm_4;
-					msgprmidx[4] = 0;
 					fsck_send_msg
-					    (fsck_BADINOODDINTRNEXT, 5);
+					    (fsck_BADINOODDINTRNEXT,
+					     fsck_ref_msg(msg_info_ptr->msg_inotyp),
+					     fsck_ref_msg(msg_info_ptr->msg_inopfx),
+					     msg_info_ptr->msg_inonum,
+					     (long long) this_key,
+					     ext_length);
 				}
 				goto out;
 			}
@@ -1136,16 +1040,10 @@ int xTree_processing(struct dinode *inoptr,
 		inorecptr->ignore_alloc_blks = 1;
 		if (desired_action == FSCK_RECORD_DUPCHECK) {
 			/* not reported yet */
-			msgprms[0] = "45";
-			msgprmidx[0] = 0;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = msg_info_ptr->msg_inotyp;
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_3, "%d", msg_info_ptr->msg_inonum);
-			msgprms[3] = message_parm_3;
-			msgprmidx[3] = 0;
-			fsck_send_msg(fsck_BADINOOTHR, 4);
+			fsck_send_msg(fsck_BADINOOTHR, "45",
+				      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+				      msg_info_ptr->msg_inonum);
 		}		/* end not reported yet */
 		goto out;
 	}
@@ -1155,16 +1053,10 @@ int xTree_processing(struct dinode *inoptr,
 		inorecptr->ignore_alloc_blks = 1;
 		if (desired_action == FSCK_RECORD_DUPCHECK) {
 			/* not reported yet */
-			msgprms[0] = "46";
-			msgprmidx[0] = 0;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = msg_info_ptr->msg_inotyp;
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_3, "%d", msg_info_ptr->msg_inonum);
-			msgprms[3] = message_parm_3;
-			msgprmidx[3] = 0;
-			fsck_send_msg(fsck_BADINOOTHR, 4);
+			fsck_send_msg(fsck_BADINOOTHR, "46",
+				      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+				      msg_info_ptr->msg_inonum);
 		}
 		goto out;
 	}
@@ -1192,12 +1084,9 @@ int xTree_processing(struct dinode *inoptr,
 		inorecptr->ignore_alloc_blks = 1;
 		if (desired_action == FSCK_RECORD_DUPCHECK) {
 			/* not reported yet */
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_1, "%d", msg_info_ptr->msg_inonum);
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = 0;
-			fsck_send_msg(fsck_BADINOFRONTGAP, 2);
+			fsck_send_msg(fsck_BADINOFRONTGAP,
+				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+				      msg_info_ptr->msg_inonum);
 		}
 		goto release;
 	}
@@ -1238,17 +1127,10 @@ int xTree_processing(struct dinode *inoptr,
 			inorecptr->ignore_alloc_blks = 1;
 			if (desired_action == FSCK_RECORD_DUPCHECK) {
 				/* not reported yet */
-				msgprms[0] = "50";
-				msgprmidx[0] = 0;
-				msgprms[1] = message_parm_1;
-				msgprmidx[1] = msg_info_ptr->msg_inotyp;
-				msgprms[2] = message_parm_2;
-				msgprmidx[2] = msg_info_ptr->msg_inopfx;
-				sprintf(message_parm_3,
-					"%d", msg_info_ptr->msg_inonum);
-				msgprms[3] = message_parm_3;
-				msgprmidx[3] = 0;
-				fsck_send_msg(fsck_BADINOOTHR, 4);
+				fsck_send_msg(fsck_BADINOOTHR, "50",
+					      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+					      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+					      msg_info_ptr->msg_inonum);
 			}
 		}
 	}
@@ -1309,17 +1191,10 @@ int xTree_processing(struct dinode *inoptr,
 			inorecptr->ignore_alloc_blks = 1;
 			if (desired_action == FSCK_RECORD_DUPCHECK) {
 				/* not reported yet */
-				msgprms[0] = "42";
-				msgprmidx[0] = 0;
-				msgprms[1] = message_parm_1;
-				msgprmidx[1] = msg_info_ptr->msg_inotyp;
-				msgprms[2] = message_parm_2;
-				msgprmidx[2] = msg_info_ptr->msg_inopfx;
-				sprintf(message_parm_3,
-					"%d", msg_info_ptr->msg_inonum);
-				msgprms[3] = message_parm_3;
-				msgprmidx[3] = 0;
-				fsck_send_msg(fsck_BADINOOTHR, 4);
+				fsck_send_msg(fsck_BADINOOTHR, "42",
+					      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+					      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+					      msg_info_ptr->msg_inonum);
 			}
 			break;
 		}
@@ -1330,18 +1205,10 @@ int xTree_processing(struct dinode *inoptr,
 			inorecptr->ignore_alloc_blks = 1;
 			if (desired_action == FSCK_RECORD_DUPCHECK) {
 				/* not reported yet */
-				msgprms[0] = "43";
-				msgprmidx[0] = 0;
-				msgprms[1] = message_parm_1;
-				msgprmidx[1] = msg_info_ptr->msg_inotyp;
-				msgprms[2] = message_parm_2;
-				msgprmidx[2] = msg_info_ptr->msg_inopfx;
-				sprintf
-				    (message_parm_3,
-				     "%d", msg_info_ptr->msg_inonum);
-				msgprms[3] = message_parm_3;
-				msgprmidx[3] = 0;
-				fsck_send_msg(fsck_BADINOOTHR, 4);
+				fsck_send_msg(fsck_BADINOOTHR, "43",
+					      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+					      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+					      msg_info_ptr->msg_inonum);
 			}
 		} else if (xtiptr->xtp_ptr->header.nextindex >
 			   xtiptr->xtp_ptr->header.maxentry) {
@@ -1349,18 +1216,10 @@ int xTree_processing(struct dinode *inoptr,
 			inorecptr->ignore_alloc_blks = 1;
 			if (desired_action == FSCK_RECORD_DUPCHECK) {
 				/* not reported yet */
-				msgprms[0] = "44";
-				msgprmidx[0] = 0;
-				msgprms[1] = message_parm_1;
-				msgprmidx[1] = msg_info_ptr->msg_inotyp;
-				msgprms[2] = message_parm_2;
-				msgprmidx[2] = msg_info_ptr->msg_inopfx;
-				sprintf
-				    (message_parm_3,
-				     "%d", msg_info_ptr->msg_inonum);
-				msgprms[3] = message_parm_3;
-				msgprmidx[3] = 0;
-				fsck_send_msg(fsck_BADINOOTHR, 4);
+				fsck_send_msg(fsck_BADINOOTHR, "44",
+					      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+					      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+					      msg_info_ptr->msg_inonum);
 			}
 		}
 		if (inorecptr->ignore_alloc_blks)
@@ -1387,21 +1246,10 @@ int xTree_processing(struct dinode *inoptr,
 			inorecptr->ignore_alloc_blks = 1;
 			if (desired_action == FSCK_RECORD_DUPCHECK) {
 				/* not reported yet */
-				msgprms[0]
-				    = message_parm_0;
-				msgprmidx[0]
-				    = msg_info_ptr->msg_inotyp;
-				msgprms[1]
-				    = message_parm_1;
-				msgprmidx[1]
-				    = msg_info_ptr->msg_inopfx;
-				sprintf(message_parm_2,
-					"%d", msg_info_ptr->msg_inonum);
-				msgprms[2]
-				    = message_parm_2;
-				msgprmidx[2]
-				    = 0;
-				fsck_send_msg(fsck_BADINONODESELF, 3);
+				fsck_send_msg(fsck_BADINONODESELF,
+					      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+					      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+					      msg_info_ptr->msg_inonum);
 			}
 		} else if (xtiptr->xtp_ptr->header.nextindex > XTENTRYSTART) {
 			if (xtiptr->xtp_ptr->header.flag & BT_LEAF) {
@@ -1430,21 +1278,10 @@ int xTree_processing(struct dinode *inoptr,
 			inorecptr->ignore_alloc_blks = 1;
 			if (desired_action == FSCK_RECORD_DUPCHECK) {
 				/* not reported yet */
-				msgprms[0]
-				    = message_parm_0;
-				msgprmidx[0]
-				    = msg_info_ptr->msg_inotyp;
-				msgprms[1]
-				    = message_parm_1;
-				msgprmidx[1]
-				    = msg_info_ptr->msg_inopfx;
-				sprintf(message_parm_2,
-					"%d", msg_info_ptr->msg_inonum);
-				msgprms[2]
-				    = message_parm_2;
-				msgprmidx[2]
-				    = 0;
-				fsck_send_msg(fsck_BADINOMTNODE, 3);
+				fsck_send_msg(fsck_BADINOMTNODE,
+					      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+					      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+					      msg_info_ptr->msg_inonum);
 			}
 		}
 
@@ -1481,17 +1318,10 @@ int xTree_processing(struct dinode *inoptr,
 				inorecptr->ignore_alloc_blks = 1;
 				if (desired_action == FSCK_RECORD_DUPCHECK) {
 					/* not reported yet */
-					msgprms[0] = "51";
-					msgprmidx[0] = 0;
-					msgprms[1] = message_parm_1;
-					msgprmidx[1] = msg_info_ptr->msg_inotyp;
-					msgprms[2] = message_parm_2;
-					msgprmidx[2] = msg_info_ptr->msg_inopfx;
-					sprintf(message_parm_3,
-						"%d", msg_info_ptr->msg_inonum);
-					msgprms[3] = message_parm_3;
-					msgprmidx[3] = 0;
-					fsck_send_msg(fsck_BADINOOTHR, 4);
+					fsck_send_msg(fsck_BADINOOTHR, "51",
+						      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+						      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+						      msg_info_ptr->msg_inonum);
 				}
 			}
 		}
@@ -1602,6 +1432,7 @@ int xTree_search(struct dinode *inoptr,
 			   offsetXAD(&(xtpg_ptr->xad[XTENTRYSTART]))) {
 			/* precedes the 1st allocation described */
 			not_there = -1;
+			xad_chosen = 0;
 		} else {
 			/* it's somewhere in between */
 			xs_rc = xTree_binsrch_page(xtpg_ptr, given_key,
