@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000
+ *   Copyright (c) International Business Machines Corp., 2000-2002
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -18,35 +18,34 @@
 #ifndef H_DEVICES
 #define H_DEVICES
 
-#define GET	 0
-#define PUT	 1
-#define VRFY 2
+#define GET	0
+#define PUT	1
+#define VRFY	2
 
 /* Macros used for determining open mode */
 #define READONLY	0
 #define RDWR_EXCL	1
 
-/* Handle used to access the device. */              
+/* Handle used to access the device. */
 #define HFILE  int
-#define PHFILE int * 
+#define PHFILE int *
 
 /* Error codes */
-#define NO_ERROR                  0
-#define ERROR_INVALID_FUNCTION	  1
-#define ERROR_FILE_NOT_FOUND	  2
-#define ERROR_INVALID_HANDLE	  6
-#define ERROR_NOT_ENOUGH_MEMORY   8 
-#define ERROR_INVALID_ACCESS	 12
-#define ERROR_SEEK		         25
-#define ERROR_WRITE_FAULT	     29
-#define ERROR_READ_FAULT	     30
-#define ERROR_GEN_FAILURE	     31
-#define ERROR_INVALID_PARAMETER	 87
-#define ERROR_DISK_FULL         112
+#define NO_ERROR		0
+#define ERROR_INVALID_FUNCTION	1
+#define ERROR_FILE_NOT_FOUND	2
+#define ERROR_INVALID_HANDLE	6
+#define ERROR_NOT_ENOUGH_MEMORY 8
+#define ERROR_INVALID_ACCESS	12
+#define ERROR_SEEK		25
+#define ERROR_WRITE_FAULT	29
+#define ERROR_READ_FAULT	30
+#define ERROR_GEN_FAILURE	31
+#define ERROR_INVALID_PARAMETER	87
+#define ERROR_DISK_FULL		112
 
-                               
-int32_t ujfs_get_dev_size( HFILE device, int64_t * size );
-int32_t ujfs_rw_diskblocks( HFILE, int64_t, int32_t, void *, int32_t );
+int ujfs_get_dev_size(HFILE device, int64_t * size);
+int ujfs_rw_diskblocks(HFILE, int64_t, int32_t, void *, int32_t);
 
 /*
  * Convert st_rdev from stat() & fstat() to kernel-compatible device number
@@ -55,4 +54,4 @@ static inline int32_t dev_to_kdev(dev_t rdev)
 {
 	return (major(rdev) << 8 | minor(rdev));
 }
-#endif /* H_DEVICES */
+#endif				/* H_DEVICES */
