@@ -22,6 +22,7 @@
 #include <memory.h>
 #include <string.h>
 #include <fcntl.h>
+#include <errno.h>
 #include "jfs_endian.h"
 #include "jfs_filsys.h"
 #include "jfs_superblock.h"
@@ -159,7 +160,6 @@ int32_t retcode;		/* return code from logredo    */
  */
 extern char *optarg;
 extern int optind;
-extern int errno;
 extern int initMaps(int32_t);
 extern int updateMaps(int);
 extern int findEndOfLog(void);
@@ -198,7 +198,6 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 {
 	int rc;
 	int32_t logaddr, nextaddr, lastaddr, nlogrecords;
-	int syncrecord;
 	struct lrd ld;
 	int32_t lowest_lr_byte = 2 * LOGPSIZE + LOGPHDRSIZE;
 	int32_t highest_lr_byte = 0;
@@ -419,7 +418,6 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 					rc = 0;
 					if (!dump_all) {	/* user just wants from last synch point forward */
 						if (lastaddr == 0) {
-							syncrecord = logaddr;
 							lastaddr = (ld.log.syncpt.sync == 0)
 							    ? logaddr : ld.log.syncpt.sync;
 						}
