@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000,2002
+ *   Copyright (c) International Business Machines Corp., 2000-2002
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -14,42 +14,16 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program;  if not, write to the Free Software 
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- *  format log
- *
- * XJFS decided to put log inside the file system.
- * The following logform utility is used to support both inline log file 
- * system and outline log file system.
- * For logform command, it should only be used when it is an outline
- * log file system.
- * in addtion, logform is called from mkfs or logredo, or extendfs 
- * (kernel code).
- *
- * command:
- *	xlogform lvname [nblocks]
- *
- * where 
- * lvname	- the name of a logical volume of the outline log device;
- * [nblocks]	- the size of the log in 512 byte blocks
- * 		  (optional paramter);
- *		  this parameter is here for bringup purpose. For
- *		  normal use, always put zero.
- *	
- * the following disk pages starting from the beginning of the log
- * are formatted:
- *
- * page 0 - not changed              
- * page 1 - log superblock
- * page 2 - A SYNC log record is written into this page at logform time
- * pages 3-N  - set to empty log pages
  */
-
+/*
+ *  format log - called from mkfs or logredo
+ */
 #include <fcntl.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <errno.h>
 #include <string.h>
-#include <uuid/uuid.h>
+#include <unistd.h>
 
 #include "jfs_endian.h"
 #include "jfs_types.h"
@@ -62,32 +36,34 @@
  * NAME:	jfs_logform
  * FUNCTION:	format file system log
  *
- * RETURN:	0 -	successful
- *		   -1 -	error occur 
+ * RETURN:	0  -	successful
+ *		-1 -	error occur 
  *
  */
 int jfs_logform(int fd,		/* this is a file descriptor
-				 * for an opened device to write log. */
-		    int aggr_blk_size, /* aggregate block size in bytes */
-		    int s_l2bsize,	/* log2 of aggr block size in bytes */
-		    uint s_flag,	/* fs superblock s_flag is passed in */
-		    int64_t log_start,	/* offset of the start of inline log in 
+				 * for an opened device to write log. 
+				 */
+		int aggr_blk_size,	/* aggregate block size in bytes */
+		int s_l2bsize,	/* log2 of aggr block size in bytes */
+		uint s_flag,	/* fs superblock s_flag is passed in */
+		int64_t log_start,	/* offset of the start of inline log in 
 					 * number of aggr blocks. For outline
-					 * log it is set as zero */
-		    int log_len,	/* inline log length in number of aggr
-					 * blks.  For outline log, it is zero
+					 * log it is set as zero 
 					 */
-		    uuid_t uuid		/* extern log: uuid of log, if null
-					 * create new, else verify that
-					 * this device's uuid matches
-					 */
-    )
-{
+		int log_len,	/* inline log length in number of aggr
+				 * blks.  For outline log, it is zero
+				 */
+		uuid_t uuid,	/* extern log: uuid of log, if null
+				 * create new, else verify that
+				 * this device's uuid matches
+				 */
+		char *label)
+{				/* volume label for external log, none if NULL */
 	int64_t log_len_in_bytes;
 	int npages, rc, k;
 	char logpages[4 * LOGPSIZE];
-	logpage_t *logp;	/* array of 4 log pages */
-	static logsuper_t log_sup;
+	struct logpage *logp;	/* array of 4 log pages */
+	static struct logsuper log_sup;
 	struct lrd *lrd_ptr;
 	int64_t log_begin;	/* the location of the beginning of the log
 				 * inside of the file system. ( in bytes )
@@ -97,8 +73,12 @@ int jfs_logform(int fd,		/* this is a file descriptor
 	int Working_counter;
 	char *Working[5];
 
+	/* find the log superblock location 
+	 */
+	log_begin = log_start << s_l2bsize;
+
 #define LOGBUFSIZE	4 * LOGPSIZE
-	logp = (logpage_t *) & logpages;
+	logp = (struct logpage *) &logpages;
 	Working[0] = "   |\r";
 	Working[1] = "   /\r";
 	Working[2] = "   -\r";
@@ -126,11 +106,10 @@ int jfs_logform(int fd,		/* this is a file descriptor
 		else {
 			/* Verify existing uuid matches uuid passed in */
 			rc = ujfs_rw_diskblocks(fd, (log_begin + LOGPSIZE),
-						(unsigned) LOGPSIZE,
-						(char *) &log_sup, GET);
+						(unsigned) LOGPSIZE, (char *) &log_sup, GET);
 			if (rc)
 				return -1;
-			ujfs_swap_logsuper_t(&log_sup);
+			ujfs_swap_logsuper(&log_sup);
 
 			if (!uuid_compare(log_sup.uuid, uuid)) {
 				printf("Invalid log device\n");
@@ -164,15 +143,15 @@ int jfs_logform(int fd,		/* this is a file descriptor
 	else
 		uuid_clear(log_sup.uuid);	/* Inline log */
 
+	if (label) {
+		strncpy((char *) &log_sup.label, label, sizeof (log_sup.label));
+	}
+
 	for (k = 0; k < MAX_ACTIVE; k++)
 		uuid_clear(log_sup.active[k]);
 
-	/* find the log superblock location 
-	 */
-	log_begin = log_start << s_l2bsize;
-
 	/* swap if on big endian machine */
-	ujfs_swap_logsuper_t(&log_sup);
+	ujfs_swap_logsuper(&log_sup);
 
 	rc = ujfs_rw_diskblocks(fd, (log_begin + LOGPSIZE),
 				(unsigned) LOGPSIZE, (char *) &log_sup, PUT);
@@ -227,13 +206,12 @@ int jfs_logform(int fd,		/* this is a file descriptor
 	lrd_ptr->log.syncpt.sync = 0;
 
 	/* swap if on big endian machine */
-	ujfs_swap_logpage_t(logp, 2);
+	ujfs_swap_logpage(logp, 2);
 
 	rc = ujfs_rw_diskblocks(fd, (log_begin + 2 * LOGPSIZE),
-				(unsigned) 2 * LOGPSIZE,
-				(char *) &(logp[0]), PUT);
+				(unsigned) 2 * LOGPSIZE, (char *) &(logp[0]), PUT);
 
-	ujfs_swap_logpage_t(logp, 2);	/* Swap back */
+	ujfs_swap_logpage(logp, 2);	/* Swap back */
 
 	if (rc != 0)
 		return -1;
@@ -269,38 +247,39 @@ int jfs_logform(int fd,		/* this is a file descriptor
 		logp[3].h.page = logp[3].t.page = k + 3;
 
 		/* swap if on big endian machine */
-		ujfs_swap_logpage_t(logp, 4);
+		ujfs_swap_logpage(logp, 4);
 
 		rc = ujfs_rw_diskblocks(fd, log_contwt,
-					(unsigned) LOGBUFSIZE,
-					(char *) &(logp[0]), PUT);
+					(unsigned) LOGBUFSIZE, (char *) &(logp[0]), PUT);
 		if (rc != 0)
 			return -1;
 
 		log_contwt += LOGBUFSIZE;
 
-		Working_counter++;
-		switch (Working_counter) {
-		case (100):
-			printf("%s", Working[0]);
-			fflush(stdout);
-			break;
-		case (200):
-			printf("%s", Working[1]);
-			fflush(stdout);
-			break;
-		case (300):
-			printf("%s", Working[2]);
-
-			fflush(stdout);
-			break;
-		case (400):
-			printf("%s", Working[3]);
-			fflush(stdout);
-			Working_counter = 0;
-			break;
-		default:
-			break;
+		/* display heartbeat, but only if output not redirected */
+		if (isatty(STDOUT_FILENO)) {
+			Working_counter++;
+			switch (Working_counter) {
+			case (100):
+				printf("%s", Working[0]);
+				fflush(stdout);
+				break;
+			case (200):
+				printf("%s", Working[1]);
+				fflush(stdout);
+				break;
+			case (300):
+				printf("%s", Working[2]);
+				fflush(stdout);
+				break;
+			case (400):
+				printf("%s", Working[3]);
+				fflush(stdout);
+				Working_counter = 0;
+				break;
+			default:
+				break;
+			}
 		}
 	}
 
