@@ -40,7 +40,7 @@
 #include "devices.h"
 #include "debug.h"
 
-#include "fsckmsgc.h"		/* for chkdsk message logging facility */
+#include "fsck_message.h"		/* for chkdsk message logging facility */
 
 /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
  *
@@ -48,24 +48,8 @@
  *
  *      defined in xchkdsk.c
  */
-extern char message_parm_0[];
-extern char message_parm_1[];
-extern char message_parm_2[];
-extern char message_parm_3[];
-extern char message_parm_4[];
-extern char message_parm_5[];
-extern char message_parm_6[];
-extern char message_parm_7[];
-extern char message_parm_8[];
-extern char message_parm_9[];
-
-extern char *msgprms[];
-extern int16_t msgprmidx[];
-
 extern char *verbose_msg_ptr;
 
-extern char *MsgText[];
-
 /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
  *
  *   L O C A L   M A C R O    D E F I N I T I O N S
@@ -189,7 +173,6 @@ int end_of_transaction = 0;
  */
 extern char *optarg;
 extern int optind;
-extern int errno;
 extern int initMaps(int32_t);
 extern int updateMaps(int);
 extern int findEndOfLog(void);
@@ -203,7 +186,7 @@ extern int doNoRedoInoExt(struct lrd *);
 extern int doAfter(struct lrd *, int32_t);
 extern int doUpdateMap(struct lrd *);
 
-extern void fsck_send_msg(int, int);
+extern int v_fsck_send_msg(int, const char *, int, ...);
 extern int alloc_wrksp(uint32_t, int, int, void **);
 
 extern int open_by_label(uuid_t, int, int, char *);
@@ -499,7 +482,6 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	int k, logaddr, nextaddr, lastaddr, nlogrecords;
 	int syncrecord = 0;
 	struct lrd ld;
-	int logformit;
 	int lowest_lr_byte = 2 * LOGPSIZE + LOGPHDRSIZE;
 	int highest_lr_byte = 0;
 	int log_has_wrapped = 0;
@@ -522,15 +504,15 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	 */
 	rc = findLog(fd);
 	if (rc < 0) {
-		fsck_send_msg(lrdo_DEVOPNREADERROR, 0);
+		fsck_send_msg(lrdo_DEVOPNREADERROR);
 		return (rc);
 	}
 
 	/* recover from extendfs() ? */
 	if (log.location & INLINELOG && (vopen[0].status & FM_EXTENDFS)) {
-		fsck_send_msg(lrdo_REXTNDBEGIN, 0);
+		fsck_send_msg(lrdo_REXTNDBEGIN);
 		rc = recoverExtendFS(fd);
-		fsck_send_msg(lrdo_REXTNDDONE, 0);
+		fsck_send_msg(lrdo_REXTNDDONE);
 		return rc;
 	}
 
@@ -544,20 +526,20 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 					    LOGPNTOB(LOGSUPER_B)),
 				(unsigned) sizeof (struct logsuper), (char *) &logsup, GET);
 	if (rc != 0) {
-		fsck_send_msg(lrdo_CANTREADLOGSUP, 0);
+		fsck_send_msg(lrdo_CANTREADLOGSUP);
 		rc = LOGSUPER_READ_ERROR;
 		goto error_out;
 	}
 	ujfs_swap_logsuper(&logsup);
 
 	if (logsup.magic != LOGMAGIC) {
-		fsck_send_msg(lrdo_LOGSUPBADMGC, 0);
+		fsck_send_msg(lrdo_LOGSUPBADMGC);
 		rc = NOT_LOG_FILE_ERROR;
 		goto error_out;
 	}
 
 	if (logsup.version > LOGVERSION) {
-		fsck_send_msg(lrdo_LOGSUPBADVER, 0);
+		fsck_send_msg(lrdo_LOGSUPBADVER);
 		rc = JFS_VERSION_ERROR;
 		goto error_out;
 	}
@@ -572,10 +554,10 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	}
 
 	if (logsup.state == LOGREDONE) {
-		fsck_send_msg(lrdo_ALREADYREDONE, 0);
+		fsck_send_msg(lrdo_ALREADYREDONE);
 		if (log.location & INLINELOG)
 			if ((rc = updateSuper(0)) != 0) {
-				fsck_send_msg(lrdo_CANTUPDLOGSUP, 0);
+				fsck_send_msg(lrdo_CANTUPDLOGSUP);
 				return (rc);
 			}
 		return (0);
@@ -590,12 +572,9 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	logend = findEndOfLog();
 
 	if (logend < 0) {
-		sprintf(message_parm_0, "0x0%x", logend);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_LOGEND, 1);
+		fsck_send_msg(lrdo_LOGEND, logend);
 
-		fsck_send_msg(lrdo_LOGENDBAD1, 0);
+		fsck_send_msg(lrdo_LOGENDBAD1);
 		logError(LOGEND, 0);
 		ujfs_swap_logsuper(&logsup);
 		rc = ujfs_rw_diskblocks(log.fd,
@@ -611,25 +590,16 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	 * the contents of its superblock
 	 */
 	if ((rc = logredoInit()) != 0) {
-		sprintf(message_parm_0, "%d", rc);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		sprintf(message_parm_1, "%d", errno);
-		msgprms[1] = message_parm_1;
-		msgprmidx[1] = 0;
-		fsck_send_msg(lrdo_INITFAILED, 2);
+		fsck_send_msg(lrdo_INITFAILED, rc, errno);
 		goto error_out;
 	}
 
 	highest_lr_byte = logsup.size * LOGPSIZE - LOGRDSIZE;
 
 	if ((logend < lowest_lr_byte) || (logend > highest_lr_byte)) {
-		sprintf(message_parm_0, "0x0%x", logend);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_LOGEND, 1);
+		fsck_send_msg(lrdo_LOGEND, logend);
 
-		fsck_send_msg(lrdo_LOGENDBAD2, 0);
+		fsck_send_msg(lrdo_LOGENDBAD2);
 		rc = INVALID_LOGEND;
 		goto error_out;
 	}
@@ -655,33 +625,27 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 		 *
 		 */
 		if (nextaddr < 0) {
-			fsck_send_msg(lrdo_NEXTADDRINVALID, 0);
+			fsck_send_msg(lrdo_NEXTADDRINVALID);
 			rc = nextaddr;
 			goto error_out;
 		}
 
 		if ((nextaddr < lowest_lr_byte)
 		    || (nextaddr > highest_lr_byte)) {
-			sprintf(message_parm_0, "0x0%x", nextaddr);
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = 0;
-			fsck_send_msg(lrdo_NEXTADDROUTRANGE, 1);
+			fsck_send_msg(lrdo_NEXTADDROUTRANGE, nextaddr);
 			rc = INVALID_NEXTADDR;
 			goto error_out;
 		}
 
 		if (nextaddr == logaddr) {
-			sprintf(message_parm_0, "0x0%x", nextaddr);
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = 0;
-			fsck_send_msg(lrdo_NEXTADDRSAME, 1);
+			fsck_send_msg(lrdo_NEXTADDRSAME, nextaddr);
 			rc = NEXTADDR_SAME;
 			goto error_out;
 		}
 
 		if (nextaddr > logaddr) {
 			if (log_has_wrapped) {
-				fsck_send_msg(lrdo_LOGWRAPPED, 0);
+				fsck_send_msg(lrdo_LOGWRAPPED);
 				rc = LOG_WRAPPED_TWICE;
 				goto error_out;
 			} else {
@@ -697,36 +661,24 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 		case LOG_COMMIT:
 			rc = doCommit(&ld);
 			if (rc) {
-				sprintf(message_parm_0, "0x0%x", logaddr);
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = 0;
-				fsck_send_msg(lrdo_BADCOMMIT, 1);
+				fsck_send_msg(lrdo_BADCOMMIT, logaddr);
 
 				goto error_out;
 			}
 			break;
 		case LOG_MOUNT:
-			sprintf(message_parm_0, "0x0%x", logaddr);
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = 0;
-			fsck_send_msg(lrdo_MOUNTRECORD, 1);
+			fsck_send_msg(lrdo_MOUNTRECORD, logaddr);
 
 			rc = doMount(&ld);
 			if (rc) {
-				sprintf(message_parm_0, "0x0%x", logaddr);
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = 0;
-				fsck_send_msg(lrdo_BADMOUNT, 1);
+				fsck_send_msg(lrdo_BADMOUNT, logaddr);
 
 				goto error_out;
 			}
 			break;
 
 		case LOG_SYNCPT:
-			sprintf(message_parm_0, "0x0%x", logaddr);
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = 0;
-			fsck_send_msg(lrdo_SYNCRECORD, 1);
+			fsck_send_msg(lrdo_SYNCRECORD, logaddr);
 
 			rc = 0;
 			if (lastaddr == 0) {
@@ -740,10 +692,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 			DBG_TRACE(("jfs_logredo:Case Log_redoPage"))
 			    rc = doAfter(&ld, logaddr);
 			if (rc) {
-				sprintf(message_parm_0, "0x0%x", logaddr);
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = 0;
-				fsck_send_msg(lrdo_BADREDOPAGE, 1);
+				fsck_send_msg(lrdo_BADREDOPAGE, logaddr);
 				goto error_out;
 			}
 			break;
@@ -752,10 +701,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 			DBG_TRACE(("jfs_logredo:Case Log_noredopage"))
 			    rc = doNoRedoPage(&ld);
 			if (rc) {
-				sprintf(message_parm_0, "0x0%x", logaddr);
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = 0;
-				fsck_send_msg(lrdo_BADNOREDOPAGE, 1);
+				fsck_send_msg(lrdo_BADNOREDOPAGE, logaddr);
 				goto error_out;
 			}
 			break;
@@ -764,10 +710,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 			DBG_TRACE(("jfs_logredo:Case Log_noredoinoext"))
 			    rc = doNoRedoInoExt(&ld);
 			if (rc) {
-				sprintf(message_parm_0, "0x0%x", logaddr);
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = 0;
-				fsck_send_msg(lrdo_BADNOREDOINOEXT, 1);
+				fsck_send_msg(lrdo_BADNOREDOINOEXT, logaddr);
 				goto error_out;
 			}
 			break;
@@ -775,31 +718,25 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 		case LOG_UPDATEMAP:
 			rc = doUpdateMap(&ld);
 			if (rc) {
-				sprintf(message_parm_0, "0x0%x", logaddr);
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = 0;
-				fsck_send_msg(lrdo_BADUPDATEMAP, 1);
+				fsck_send_msg(lrdo_BADUPDATEMAP, logaddr);
 				goto error_out;
 			}
 			break;
 
 		default:
-			sprintf(message_parm_0, "0x0%x", logaddr);
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = 0;
-			fsck_send_msg(lrdo_UNKNOWNTYPE, 1);
+			fsck_send_msg(lrdo_UNKNOWNTYPE, logaddr);
 			rc = UNRECOG_LOGRECTYP;
 			goto error_out;
 			break;
 		}
 
 		if (rc < 0) {
-			fsck_send_msg(lrdo_ERRORNEEDREFORMAT, 0);
+			fsck_send_msg(lrdo_ERRORNEEDREFORMAT);
 			goto error_out;
 		}
 
 		if (rc != 0) {
-			fsck_send_msg(lrdo_ERRORCANTCONTIN, 0);
+			fsck_send_msg(lrdo_ERRORCANTCONTIN);
 			goto error_out;
 		}
 
@@ -829,11 +766,6 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 		rc = doExtDtPg();
 	}
 
-	/*
-	 * run logform?
-	 */
-	logformit = (rc < 0);
-
 	/*
 	 * flush data page buffer cache
 	 */
@@ -849,7 +781,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	 * of volumes which are open if they were modified here.
 	 * i.e. if they were not previously unmounted cleanly.
 	 */
-	for (k = 0; k < MAX_ACTIVE + 1; k++) {
+	for (k = 0; k < MAX_ACTIVE; k++) {
 		if (vopen[k].state != VOPEN_OPEN)
 			continue;
 
@@ -858,13 +790,13 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 		 */
 		if (!vopen[k].is_fsdirty) {
 			if ((rc = updateMaps(k)) != 0) {
-				fsck_send_msg(lrdo_ERRORCANTUPDMAPS, 0);
+				fsck_send_msg(lrdo_ERRORCANTUPDMAPS);
 				goto error_out;
 			}
 		}
 
 		if ((rc = updateSuper(k)) != 0) {
-			fsck_send_msg(lrdo_ERRORCANTUPDFSSUPER, 0);
+			fsck_send_msg(lrdo_ERRORCANTUPDFSSUPER);
 			goto error_out;
 		}
 	}
@@ -892,35 +824,17 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	/*
 	 * now log some info for the curious
 	 */
-	sprintf(message_parm_0, "0x0%x", logend);
-	msgprms[0] = message_parm_0;
-	msgprmidx[0] = 0;
-	fsck_send_msg(lrdo_LOGEND, 1);
+	fsck_send_msg(lrdo_LOGEND, logend);
 
-	sprintf(message_parm_0, "0x0%x", syncrecord);
-	msgprms[0] = message_parm_0;
-	msgprmidx[0] = 0;
-	fsck_send_msg(lrdo_RPTSYNCNUM, 1);
+	fsck_send_msg(lrdo_RPTSYNCNUM, syncrecord);
 
-	sprintf(message_parm_0, "0x0%x", lastaddr);
-	msgprms[0] = message_parm_0;
-	msgprmidx[0] = 0;
-	fsck_send_msg(lrdo_RPTSYNCADDR, 1);
+	fsck_send_msg(lrdo_RPTSYNCADDR, lastaddr);
 
-	sprintf(message_parm_0, "(d) %d", nlogrecords);
-	msgprms[0] = message_parm_0;
-	msgprmidx[0] = 0;
-	fsck_send_msg(lrdo_RPTNUMLOGREC, 1);
+	fsck_send_msg(lrdo_RPTNUMLOGREC, nlogrecords);
 
-	sprintf(message_parm_0, "(d) %d", numdoblk);
-	msgprms[0] = message_parm_0;
-	msgprmidx[0] = 0;
-	fsck_send_msg(lrdo_RPTNUMDOBLK, 1);
+	fsck_send_msg(lrdo_RPTNUMDOBLK, numdoblk);
 
-	sprintf(message_parm_0, "(d) %d", numnodofile);
-	msgprms[0] = message_parm_0;
-	msgprmidx[0] = 0;
-	fsck_send_msg(lrdo_RPTNUMNODOBLK, 1);
+	fsck_send_msg(lrdo_RPTNUMNODOBLK, numnodofile);
 
       error_out:
 
@@ -991,7 +905,7 @@ int openVol(int vol)
 
 	/* read superblock of the aggregate/volume */
 	if ((rc = rdwrSuper(vopen[vol].fd, &sb, PB_READ)) != 0) {
-		fsck_send_msg(lrdo_CANTREADFSSUPER, 0);
+		fsck_send_msg(lrdo_CANTREADFSSUPER);
 
 		fsError(READERR, vol, SUPER1_B);
 		vopen[vol].state = VOPEN_CLOSED;
@@ -1002,18 +916,18 @@ int openVol(int vol)
 	 * values in the vopen struct for this vol.
 	 */
 	if (strncmp(sb.s_magic, JFS_MAGIC, (unsigned) strlen(JFS_MAGIC))) {
-		fsck_send_msg(lrdo_FSSUPERBADMAGIC, 0);
+		fsck_send_msg(lrdo_FSSUPERBADMAGIC);
 		vopen[vol].state = VOPEN_CLOSED;
 		return (LOGSUPER_BADMAGIC);
 	}
 	if (sb.s_version > JFS_VERSION) {
-		fsck_send_msg(lrdo_FSSUPERBADMAGIC, 0);
+		fsck_send_msg(lrdo_FSSUPERBADMAGIC);
 		vopen[vol].state = VOPEN_CLOSED;
 		return (LOGSUPER_BADVERSION);
 	}
 
 	if (log.location & OUTLINELOG && (sb.s_flag & (JFS_INLINELOG == JFS_INLINELOG))) {
-		fsck_send_msg(lrdo_FSSUPERBADLOGLOC, 0);
+		fsck_send_msg(lrdo_FSSUPERBADLOGLOC);
 		vopen[vol].state = VOPEN_CLOSED;
 		return (LOGSUPER_BADLOGLOC);
 	}
@@ -1038,18 +952,18 @@ int openVol(int vol)
 		 * more validation of the log superblock
 		 */
 		if (logsup.bsize != vopen[vol].lblksize) {
-			fsck_send_msg(lrdo_LOGSUPBADBLKSZ, 0);
+			fsck_send_msg(lrdo_LOGSUPBADBLKSZ);
 			return JFS_BLKSIZE_ERROR;
 		}
 
 		if (logsup.l2bsize != vopen[vol].l2bsize) {
-			fsck_send_msg(lrdo_LOGSUPBADL2BLKSZ, 0);
+			fsck_send_msg(lrdo_LOGSUPBADL2BLKSZ);
 			return JFS_L2BLKSIZE_ERROR;
 		}
 
 		aggsb_numpages = lengthPXD(&sb.s_logpxd) * logsup.bsize / LOGPSIZE;
 		if (logsup.size != aggsb_numpages) {
-			fsck_send_msg(lrdo_LOGSUPBADLOGSZ, 0);
+			fsck_send_msg(lrdo_LOGSUPBADLOGSZ);
 			return JFS_LOGSIZE_ERROR;
 		}
 	}
@@ -1077,7 +991,7 @@ int openVol(int vol)
 	 *check log serial number
 	 */
 	if (sb.s_logserial != log.serial) {
-		fsck_send_msg(lrdo_FSSUPERBADLOGSER, 0);
+		fsck_send_msg(lrdo_FSSUPERBADLOGSER);
 		vopen[vol].state = VOPEN_CLOSED;
 		fsError(SERIALNO, vol, SUPER1_B);
 		return (LOGSUPER_BADSERIAL);
@@ -1086,7 +1000,7 @@ int openVol(int vol)
 	/* initialize the disk and inode maps
 	 */
 	if ((rc = initMaps(vol)) != 0) {
-		fsck_send_msg(lrdo_INITMAPSFAIL, 0);
+		fsck_send_msg(lrdo_INITMAPSFAIL);
 		fsError(MAPERR, vol, 0);
 		return (rc);
 	}
@@ -1107,7 +1021,7 @@ int updateSuper(int vol)
 
 	/* read in superblock of the volume */
 	if ((rc = rdwrSuper(vopen[vol].fd, &sb, PB_READ)) != 0) {
-		fsck_send_msg(lrdo_READFSSUPERFAIL, 0);
+		fsck_send_msg(lrdo_READFSSUPERFAIL);
 		return (FSSUPER_READERROR2);
 	}
 
@@ -1119,7 +1033,7 @@ int updateSuper(int vol)
 		sb.s_state = FM_CLEAN;
 
 	if ((rc = rdwrSuper(vopen[vol].fd, &sb, PB_UPDATE)) != 0) {
-		fsck_send_msg(lrdo_WRITEFSSUPERFAIL, 0);
+		fsck_send_msg(lrdo_WRITEFSSUPERFAIL);
 	}
 
 	return (rc);
@@ -1164,10 +1078,10 @@ int rdwrSuper(int32_t fd, struct superblock * sb, int32_t rwflag)
 					(unsigned) SIZE_OF_SUPER, super.block, GET);
 		if (rc != 0) {
 			if (!use_2ndary_agg_superblock) {
-				fsck_send_msg(lrdo_READFSPRIMSBFAIL, 0);
+				fsck_send_msg(lrdo_READFSPRIMSBFAIL);
 				return (CANTREAD_PRIMFSSUPER);
 			} else {
-				fsck_send_msg(lrdo_READFS2NDSBFAIL, 0);
+				fsck_send_msg(lrdo_READFS2NDSBFAIL);
 				return (CANTREAD_2NDFSSUPER);
 			}
 		}
@@ -1193,10 +1107,10 @@ int rdwrSuper(int32_t fd, struct superblock * sb, int32_t rwflag)
 					(unsigned) SIZE_OF_SUPER, super.block, PUT);
 		if (rc != 0) {
 			if (!use_2ndary_agg_superblock) {
-				fsck_send_msg(lrdo_WRITEFSPRIMSBFAIL, 0);
+				fsck_send_msg(lrdo_WRITEFSPRIMSBFAIL);
 				return (CANTWRITE_PRIMFSSUPER);
 			} else {
-				fsck_send_msg(lrdo_WRITEFS2NDSBFAIL, 0);
+				fsck_send_msg(lrdo_WRITEFS2NDSBFAIL);
 				return (CANTWRITE_2NDFSSUPER);
 			}
 		}
@@ -1233,7 +1147,7 @@ int bflush(int32_t k,		/*  The index in bufhdr that describes buf */
 				(uint64_t) (blkno << vopen[vol].l2bsize),
 				(unsigned) nbytes, (char *) buf, PUT);
 	if (rc != 0) {
-		fsck_send_msg(lrdo_BUFFLUSHFAIL, 0);
+		fsck_send_msg(lrdo_BUFFLUSHFAIL);
 		return (BFLUSH_WRITEERROR);
 	}
 
@@ -1260,7 +1174,7 @@ int findLog(int fd)
 	 * try the LV as file system with in-line log
 	 */
 	if (rdwrSuper(fd, &sb, PB_READ)) {
-		fsck_send_msg(lrdo_NOTAFSDEV, 0);
+		fsck_send_msg(lrdo_NOTAFSDEV);
 		return NOT_FSDEV_ERROR;
 	}
 
@@ -1328,7 +1242,7 @@ int findLog(int fd)
 	ujfs_rw_diskblocks(fd, LOGPNTOB(LOGSUPER_B), sizeof (struct logsuper), &logsup, GET);
 	ujfs_swap_logsuper(&logsup);
 	if (logsup.magic != LOGMAGIC) {
-		fsck_send_msg(lrdo_NOTAFSDEV, 0);
+		fsck_send_msg(lrdo_NOTAFSDEV);
 		return NOT_FSDEV_ERROR;
 	}
 	log.fd = fd;
@@ -1350,53 +1264,35 @@ int fsError(int type,		/* error types */
 	    int64_t bn)
 {				/* aggregate block No.  */
 
-	sprintf(message_parm_0, "(d) %d", vol);
-	msgprms[0] = message_parm_0;
-	msgprmidx[0] = 0;
-	fsck_send_msg(lrdo_ERRORONVOL, 1);
+	fsck_send_msg(lrdo_ERRORONVOL, vol);
 
 	retcode = -1;
 	vopen[vol].status = FM_LOGREDO;
 
 	switch (type) {
 	case OPENERR:
-		fsck_send_msg(lrdo_OPENFAILED, 0);
+		fsck_send_msg(lrdo_OPENFAILED);
 		break;
 	case MAPERR:
-		fsck_send_msg(lrdo_CANTINITMAPS, 0);
+		fsck_send_msg(lrdo_CANTINITMAPS);
 		break;
 	case DBTYPE:
-		sprintf(message_parm_0, "0x0%llx", (long long) bn);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_BADDISKBLKNUM, 1);
+		fsck_send_msg(lrdo_BADDISKBLKNUM, (long long) bn);
 		break;
 	case INOTYPE:
-		sprintf(message_parm_0, "(d) %lld", (long long) bn);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_BADINODENUM, 1);
+		fsck_send_msg(lrdo_BADINODENUM, (long long) bn);
 		break;
 	case READERR:
-		sprintf(message_parm_0, "0x0%llx", (long long) bn);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_CANTREADBLK, 1);
+		fsck_send_msg(lrdo_CANTREADBLK, (long long) bn);
 		break;
 	case SERIALNO:
-		fsck_send_msg(lrdo_BADLOGSER, 0);
+		fsck_send_msg(lrdo_BADLOGSER);
 		break;
 	case IOERROR:
-		sprintf(message_parm_0, "0x0%llx", (long long) bn);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_IOERRREADINGBLK, 1);
+		fsck_send_msg(lrdo_IOERRREADINGBLK, (long long) bn);
 		break;
 	case LOGRCERR:
-		sprintf(message_parm_0, "(d) %lld", (long long) bn);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_BADUPDMAPREC, 1);
+		fsck_send_msg(lrdo_BADUPDMAPREC, (long long) bn);
 		break;
 	}
 	return (0);
@@ -1414,33 +1310,24 @@ int logError(int type, int logaddr)
 	logsup.state = LOGREADERR;
 	switch (type) {
 	case LOGEND:
-		fsck_send_msg(lrdo_FINDLOGENDFAIL, 1);
+		fsck_send_msg(lrdo_FINDLOGENDFAIL);
 		break;
 	case READERR:
-		sprintf(message_parm_0, "0x0%x", logaddr);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_LOGREADFAIL, 1);
+		fsck_send_msg(lrdo_LOGREADFAIL, logaddr);
 		break;
 	case UNKNOWNR:
-		sprintf(message_parm_0, "0x0%x", logaddr);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_UNRECOGTYPE, 1);
+		fsck_send_msg(lrdo_UNRECOGTYPE, logaddr);
 		break;
 	case IOERROR:
-		sprintf(message_parm_0, "0x0%x", logaddr);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_IOERRONLOG, 1);
+		fsck_send_msg(lrdo_IOERRONLOG, logaddr);
 		break;
 	case LOGWRAP:
-		fsck_send_msg(lrdo_LOGWRAP, 0);
+		fsck_send_msg(lrdo_LOGWRAP);
 	}
 
 	/* mark all open volumes in error
 	 */
-	for (k = 0; k < MAX_ACTIVE + 1; k++) {
+	for (k = 0; k < MAX_ACTIVE; k++) {
 		if ((vopen[k].state == VOPEN_OPEN) && vopen[k].status != FM_CLEAN)
 			vopen[k].status = FM_LOGREDO;
 	}
@@ -1461,7 +1348,6 @@ int logError(int type, int logaddr)
  */
 static int recoverExtendFS(int32_t fd)
 {
-	int rc;
 	struct superblock *sbp;
 	struct dinode *dip1, *dip2;
 	struct dbmap *bgcp;
@@ -1477,13 +1363,13 @@ static int recoverExtendFS(int32_t fd)
 	 */
 	/* read superblock yet again */
 	sbp = (struct superblock *) &buffer[0];
-	if ((rc = rdwrSuper(fd, sbp, PB_READ)))
+	if (rdwrSuper(fd, sbp, PB_READ))
 		goto errout;
 
 	/* read primary block allocation map inode */
 	dip = (char *) &buffer[1];
-	if ((rc = ujfs_rw_diskblocks(fd, AITBL_OFF, PSIZE, dip, GET))) {
-		fsck_send_msg(lrdo_EXTFSREADFSSUPERFAIL, 0);
+	if (ujfs_rw_diskblocks(fd, AITBL_OFF, PSIZE, dip, GET)) {
+		fsck_send_msg(lrdo_EXTFSREADFSSUPERFAIL);
 		goto errout;
 	}
 
@@ -1503,8 +1389,8 @@ static int recoverExtendFS(int32_t fd)
 	do {
 		/* read in the leftmost child page */
 		t64 = addressXAD(&p->xad[XTENTRYSTART]) << sbp->s_l2bsize;
-		if ((rc = ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET))) {
-			fsck_send_msg(lrdo_EXTFSREADBLKMAPINOFAIL, 0);
+		if (ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET)) {
+			fsck_send_msg(lrdo_EXTFSREADBLKMAPINOFAIL);
 			goto errout;
 		}
 
@@ -1516,11 +1402,8 @@ static int recoverExtendFS(int32_t fd)
 
       rdbgcp:
 	t64 = addressXAD(&p->xad[XTENTRYSTART]) << sbp->s_l2bsize;
-	if ((rc = ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET))) {
-		sprintf(message_parm_0, "0x0%llx", (long long) t64);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_EXTFSREADBLKFAIL1, 1);
+	if (ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET)) {
+		fsck_send_msg(lrdo_EXTFSREADBLKFAIL1, (long long) t64);
 		goto errout;
 	}
 	bgcp = (struct dbmap *) bp;
@@ -1541,11 +1424,8 @@ static int recoverExtendFS(int32_t fd)
 	 */
 	/* read 2ndary block allocation map inode */
 	t64 = addressPXD(&sbp->s_ait2) << sbp->s_l2bsize;
-	if ((rc = ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET))) {
-		sprintf(message_parm_0, "0x0%llx", (long long) t64);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_EXTFSREADBLKFAIL2, 1);
+	if (ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET)) {
+		fsck_send_msg(lrdo_EXTFSREADBLKFAIL2, (long long) t64);
 		goto errout;
 	}
 	dip2 = (struct dinode *) bp;
@@ -1561,11 +1441,8 @@ static int recoverExtendFS(int32_t fd)
 	memcpy(dip1, dip2, DISIZE);
 	memcpy((void *) &(dip1->di_ixpxd), (void *) &temp_pxd, sizeof (pxd_t));
 
-	if ((rc = ujfs_rw_diskblocks(fd, AITBL_OFF, PSIZE, dip, PUT))) {
-		sprintf(message_parm_0, "0x0%x", AITBL_OFF);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_EXTFSWRITEBLKFAIL1, 1);
+	if (ujfs_rw_diskblocks(fd, AITBL_OFF, PSIZE, dip, PUT)) {
+		fsck_send_msg(lrdo_EXTFSWRITEBLKFAIL1, AITBL_OFF);
 		goto errout;
 	}
 
@@ -1616,11 +1493,8 @@ static int recoverExtendFS(int32_t fd)
 					 * pages
 					 */
 					p->header.next = 0;
-					if ((rc = ujfs_rw_diskblocks(fd, t64, PSIZE, p, PUT))) {
-						sprintf(message_parm_0, "0x0%llx", (long long) t64);
-						msgprms[0] = message_parm_0;
-						msgprmidx[0] = 0;
-						fsck_send_msg(lrdo_EXTFSWRITEBLKFAIL2, 1);
+					if (ujfs_rw_diskblocks(fd, t64, PSIZE, p, PUT)) {
+						fsck_send_msg(lrdo_EXTFSWRITEBLKFAIL2, (long long) t64);
 						goto errout;
 					}
 				}
@@ -1635,21 +1509,15 @@ static int recoverExtendFS(int32_t fd)
 			if (xaddr) {
 				if (xaddr >= barrier) {
 					p->header.next = 0;
-					if ((rc = ujfs_rw_diskblocks(fd, t64, PSIZE, p, PUT))) {
-						sprintf(message_parm_0, "0x0%llx", (long long) t64);
-						msgprms[0] = message_parm_0;
-						msgprmidx[0] = 0;
-						fsck_send_msg(lrdo_EXTFSWRITEBLKFAIL3, 1);
+					if (ujfs_rw_diskblocks(fd, t64, PSIZE, p, PUT)) {
+						fsck_send_msg(lrdo_EXTFSWRITEBLKFAIL3, (long long) t64);
 						break;
 					}
 				}
 
 				t64 = xaddr << sbp->s_l2bsize;
-				if ((rc = ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET))) {
-					sprintf(message_parm_0, "0x0%llx", (long long) t64);
-					msgprms[0] = message_parm_0;
-					msgprmidx[0] = 0;
-					fsck_send_msg(lrdo_EXTFSREADBLKFAIL3, 1);
+				if (ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET)) {
+					fsck_send_msg(lrdo_EXTFSREADBLKFAIL3, (long long) t64);
 					goto errout;
 				}
 
@@ -1666,11 +1534,8 @@ static int recoverExtendFS(int32_t fd)
 			/* get the leftmost child page  */
 			xaddr = lmchild;
 			t64 = xaddr << sbp->s_l2bsize;
-			if ((rc = ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET))) {
-				sprintf(message_parm_0, "0x0%llx", (long long) t64);
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = 0;
-				fsck_send_msg(lrdo_EXTFSREADBLKFAIL4, 1);
+			if (ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET)) {
+				fsck_send_msg(lrdo_EXTFSREADBLKFAIL4, (long long) t64);
 				goto errout;
 			}
 
@@ -1699,8 +1564,8 @@ static int recoverExtendFS(int32_t fd)
 	 *  reconstruct maps
 	 */
 	/* open LV and initialize maps  */
-	if ((rc = logredoInit())) {
-		fsck_send_msg(lrdo_EXTFSINITLOGREDOFAIL, 0);
+	if (logredoInit()) {
+		fsck_send_msg(lrdo_EXTFSINITLOGREDOFAIL);
 		goto errout;
 	}
 
@@ -1721,7 +1586,7 @@ static int recoverExtendFS(int32_t fd)
 	/* update superblock */
 	updateSuper(0);
 
-	fsck_send_msg(lrdo_REXTNDTOPRE, 0);
+	fsck_send_msg(lrdo_REXTNDTOPRE);
 
 	return 0;
 
@@ -1734,11 +1599,8 @@ static int recoverExtendFS(int32_t fd)
 	 */
 	/* read 2ndary block allocation map inode */
 	t64 = addressPXD(&sbp->s_ait2) << sbp->s_l2bsize;
-	if ((rc = ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET))) {
-		sprintf(message_parm_0, "0x0%llx", (long long) t64);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_EXTFSREADBLKFAIL5, 1);
+	if (ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET)) {
+		fsck_send_msg(lrdo_EXTFSREADBLKFAIL5, (long long) t64);
 		goto errout;
 	}
 	dip2 = (struct dinode *) bp;
@@ -1753,11 +1615,8 @@ static int recoverExtendFS(int32_t fd)
 	memcpy(dip2, dip1, DISIZE);
 	memcpy((void *) &(dip2->di_ixpxd), (void *) &temp_pxd, sizeof (pxd_t));
 
-	if ((rc = ujfs_rw_diskblocks(fd, t64, PSIZE, bp, PUT))) {
-		sprintf(message_parm_0, "0x0%llx", (long long) t64);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		fsck_send_msg(lrdo_EXTFSWRITEBLKFAIL4, 1);
+	if (ujfs_rw_diskblocks(fd, t64, PSIZE, bp, PUT)) {
+		fsck_send_msg(lrdo_EXTFSWRITEBLKFAIL4, (long long) t64);
 		goto errout;
 	}
 
@@ -1775,8 +1634,8 @@ static int recoverExtendFS(int32_t fd)
 	sbp->s_logpxd = sbp->s_xlogpxd;
 	sbp->s_logserial = 1;
 
-	if ((rc = rdwrSuper(fd, sbp, PB_UPDATE))) {
-		fsck_send_msg(lrdo_EXTFSWRITEFSSUPERFAIL, 0);
+	if (rdwrSuper(fd, sbp, PB_UPDATE)) {
+		fsck_send_msg(lrdo_EXTFSWRITEFSSUPERFAIL);
 		goto errout;
 	}
 
@@ -1787,28 +1646,25 @@ static int recoverExtendFS(int32_t fd)
 	 */
 	/* read log superblock */
 	t64 = (addressPXD(&sbp->s_logpxd) << sbp->s_l2bsize) + LOGPSIZE;
-	if ((rc = ujfs_rw_diskblocks(fd, t64, LOGPSIZE, &logsup, GET))) {
-		fsck_send_msg(lrdo_EXTFSREADLOGSUPFAIL, 0);
+	if (ujfs_rw_diskblocks(fd, t64, LOGPSIZE, &logsup, GET)) {
+		fsck_send_msg(lrdo_EXTFSREADLOGSUPFAIL);
 		goto errout;
 	}
 
 	logsup.end = findEndOfLog();
 	logsup.state = LOGREDONE;
 
-	if ((rc = ujfs_rw_diskblocks(fd, t64, LOGPSIZE, &logsup, PUT))) {
-		fsck_send_msg(lrdo_EXTFSWRITELOGSUPFAIL, 0);
+	if (ujfs_rw_diskblocks(fd, t64, LOGPSIZE, &logsup, PUT)) {
+		fsck_send_msg(lrdo_EXTFSWRITELOGSUPFAIL);
 		goto errout;
 	}
 
-	fsck_send_msg(lrdo_REXTNDTOPOST, 0);
+	fsck_send_msg(lrdo_REXTNDTOPOST);
 
 	return 0;
 
       errout:
-	sprintf(message_parm_0, "%d", errno);
-	msgprms[0] = message_parm_0;
-	msgprmidx[0] = 0;
-	fsck_send_msg(lrdo_REXTNDFAIL, 1);
+	fsck_send_msg(lrdo_REXTNDFAIL, errno);
 	return (EXTENDFS_FAILRECOV);
 }
 
