@@ -1,32 +1,23 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000
+ *   Copyright (c) International Business Machines Corp., 2000-2002
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 2 of the License, or 
  *   (at your option) any later version.
- *
+ * 
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software
+ *   along with this program;  if not, write to the Free Software 
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- *   MODULE_NAME:	logredo.h
- *
- *   COMPONENT_NAME: 	jfslib
- *
- *   FUNCTIONS: none
- *
  */
 #ifndef H_LOGREDO
 #define H_LOGREDO
 
-#include <uuid/uuid.h>
-
 /*
  * NOTE:
  *	If logredo passes rc > 0 to fsck,
@@ -128,7 +119,6 @@
 #define BMAP_READERROR7 	 271
 #define READLOGERROR		-272
 
-
 /* error types
  */
 #define MAPERR    0
@@ -148,55 +138,52 @@
 /* log.location */
 #define INLINELOG	0x1
 #define OUTLINELOG	0x2
-#define NEWLOG		0x4
 
 #define NBUFPOOL  128
 
-
 /*
  * the following are used to map the bmap_wsp array elements
  * which describe block map pages
  */
-typedef struct {
+struct dmap_bitmaps {
 	uint32_t wmap[LPERDMAP];	/* 1024: bits of the working map    */
 	uint32_t pmap[LPERDMAP];	/* 1024: bits of the persistent map */
-} dmap_bitmaps_t;		/* - 2048 -                         */
+};				/* - 2048 -                         */
 
-typedef struct {
+struct bmap_wsp {
 	int64_t page_offset;	/* aggregate offset for the page */
-	dmap_bitmaps_t *dmap_bitmaps;	/*
-					 * IF this record describes a dmap page,
-					 * AND IF that dmap page is affected by
-					 * transactions processed in this
-					 * logredo session, THEN this field is
-					 * a ptr to bit maps for the page.
-					 * Otherwise this field is null.
-					 */
+	struct dmap_bitmaps *dmap_bitmaps;	/*
+						   * IF this record describes a dmap page,
+						   * AND IF that dmap page is affected by
+						   * transactions processed in this
+						   * logredo session, THEN this field is
+						   * a ptr to bit maps for the page.
+						   * Otherwise this field is null.
+						 */
 	uint32_t available;	/* unused at this time  */
-} bmap_wsp_t;
-
+};
 
 /*
  * the following are used to map the imap_wsp array elements
  * which describe the inode map pages
  */
-typedef struct {
+struct iag_data {
 	uint32_t wmap[EXTSPERIAG];	/* 512: working allocation map    */
 	uint32_t pmap[EXTSPERIAG];	/* 512: persistent allocation map */
 	pxd_t inoext[EXTSPERIAG];	/* 1024: inode extent addresses   */
-} iag_data_t;			/* - 2048 -                       */
+};				/* - 2048 -                       */
 
-typedef struct {
+struct imap_wsp {
 	int64_t page_offset;	/* aggregate offset for the page */
-	iag_data_t *imap_data;	/* IF this record describes an IAG
-				 *    AND IF that IAG is affected by
-				 *    transactions processed in this
-				 *    logredo session, THEN this field
-				 *    is a ptr to data for the IAG.
-				 *    Otherwise this field is null.
-				 */
+	struct iag_data *imap_data;	/* IF this record describes an IAG
+					   *    AND IF that IAG is affected by
+					   *    transactions processed in this
+					   *    logredo session, THEN this field
+					   *    is a ptr to data for the IAG.
+					   *    Otherwise this field is null.
+					 */
 	uint32_t available;	/* unused at this time  */
-} imap_wsp_t;
+};
 
 /*
  * Information about the log device
@@ -233,27 +220,27 @@ struct vopen {
 	int32_t agsize;		/* num of aggre. blks per alloc group  */
 	int32_t l2agsize;	/* Log2 of agsize   */
 	int32_t numag;		/* total num of ags in this aggregate. */
-	dinomap_t *aggimap_ctrl;	/* pointer to the control page of
+	struct dinomap *aggimap_ctrl;	/* pointer to the control page of
 					   aggregate inode map */
-	iag_t *aggimap_iag;	/* ptr to aggregate inode map iag pages */
+	struct iag *aggimap_iag;	/* ptr to aggregate inode map iag pages */
 	struct fsimap_lst {
 		int32_t fileset;	/* fileset number, which is the inode
 					 * number of this fileset imap inode in
 					 * the aggregate inode table.
 					 */
 		int imap_page_count;	/* number of pages in the imap,
-						 * including the control page
-						 */
-		dinomap_t *fsimapctrl;	/* ptr to ctrl page of fileset imap */
-
-		imap_wsp_t *imap_wsp;	/*
-					 * ptr to an array of IAG workspaces
+					   * including the control page
 					 */
-		iag_t *iag_pbuf;	/* ptr to an iag page buffer */
+		struct dinomap *fsimapctrl;	/* ptr to ctrl page of fileset imap */
+
+		struct imap_wsp *imap_wsp;	/*
+						   * ptr to an array of IAG workspaces
+						 */
+		struct iag *iag_pbuf;	/* ptr to an iag page buffer */
 		int imap_pagenum;	/* page offset, in inode map,
 					 * of buffer contents
 					 */
-		iag_t *iag_pbuf2;	/* ptr to another iag page buffer */
+		struct iag *iag_pbuf2;	/* ptr to another iag page buffer */
 		int imap_pagenum2;	/* page offset, in inode map,
 					 * of buffer contents
 					 */
@@ -263,25 +250,25 @@ struct vopen {
 	int bmap_page_count;	/* number of pages in the bmap,
 				 * including the control page
 				 */
-	dbmap_t *bmap_ctl;	/* ptr to control page of aggregate block
+	struct dbmap *bmap_ctl;	/* ptr to control page of aggregate block
 				 * allocate map (i.e. bmap) file
 				 */
-	bmap_wsp_t *bmap_wsp;	/*
-				 * ptr to an array of blockmap page workspaces
-				 */
-	dmap_t *dmap_pbuf;	/* ptr to a dmap page buffer */
+	struct bmap_wsp *bmap_wsp;	/*
+					   * ptr to an array of blockmap page workspaces
+					 */
+	struct dmap *dmap_pbuf;	/* ptr to a dmap page buffer */
 	int dmap_pagenum;	/* page offset, in block map, of
 				 * buffer contents
 				 */
-	dmapctl_t *L0_pbuf;	/* ptr to a dmap page buffer */
+	struct dmapctl *L0_pbuf;	/* ptr to a dmap page buffer */
 	int L0_pagenum;		/* page offset, in block map, of
 				 * buffer contents
 				 */
-	dmapctl_t *L1_pbuf;	/* ptr to a dmap page buffer */
+	struct dmapctl *L1_pbuf;	/* ptr to a dmap page buffer */
 	int L1_pagenum;		/* page offset, in block map, of
 				 * buffer contents
 				 */
-	dmapctl_t *L2_pbuf;	/* ptr to a dmap page buffer */
+	struct dmapctl *L2_pbuf;	/* ptr to a dmap page buffer */
 	int L2_pagenum;		/* page offset, in block map, of
 				 * buffer contents
 				 */
@@ -294,6 +281,7 @@ struct vopen {
 
 #define  fsimap_iag     fsimap_lst.fsimapiag
 
-int32_t jfs_logredo(caddr_t, int32_t, int32_t);
+int jfs_logredo(caddr_t, int32_t, int32_t);
+int findLog(int);
 
 #endif				/* H_LOGREDO */
