@@ -16,6 +16,7 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 #include "jfs_types.h"
+#include <sys/stat.h>
 #include <stdio.h>
 #include <string.h>
 #include <fcntl.h>
@@ -70,15 +71,69 @@ int open_check_label(char *device, uuid_t uuid, int is_label, int is_log)
 	return (-ENOENT);
 }
 
+/*--------------------------------------------------------------------
+ * NAME: walk_dir
+ *
+ * FUNCTION: Helper for open_by_label to recursively search a directory
+ *	     for block devices with the specified label or uuid
+ *
+ * PARAMETERS:	path - path of directory to search, returns found device
+ *		uuid - label or uuid
+ * 		is_label - 1 if label, 0 if uuid
+ * 		is_log - 0 if filesystem, 1 if external log
+ *
+ * RETURNS:
+ *    >= 0 file descriptor of matching volume
+ *    < 0  matching volume not found
+ */
+int walk_dir(char *path, uuid_t uuid, int is_label, int is_log)
+{
+	int fd;
+	DIR *lv_dir;
+	struct dirent *lv_ent;
+	int path_len;
+	struct stat st;
+
+	lv_dir = opendir(path);
+	if (lv_dir) {
+		strcat(path, "/");
+		path_len = strlen(path);
+		while ((lv_ent = readdir(lv_dir))) {
+			path[path_len] = 0;
+			if (!strcmp(lv_ent->d_name, ".") ||
+			    !strcmp(lv_ent->d_name, "..") || 
+			    !strcmp(lv_ent->d_name, ".nodes"))
+				continue;
+			strcat(path, lv_ent->d_name);
+			if (stat(path, &st))
+				continue;
+			if (S_ISBLK(st.st_mode))
+				fd = open_check_label(path, uuid, is_label,
+						      is_log);
+			else if (S_ISDIR(st.st_mode))
+				fd = walk_dir(path, uuid, is_label, is_log);
+			else 
+				continue;
+			if (fd >= 0) {
+				closedir(lv_dir);
+				return fd;
+			}
+		}
+		closedir(lv_dir);
+	}
+	return -ENOENT;
+}
+
 /*--------------------------------------------------------------------
  * NAME: open_by_label
  *
  * FUNCTION: Search /proc/partitions for volume having specified
  *	     label or uuid
  *
- * PARAMETERS:	label - label or uuid
+ * PARAMETERS:	uuid - label or uuid
  * 		is_label - 1 if label, 0 if uuid
  * 		is_log - 0 if filesystem, 1 if external log
+ *		dev - if not null, returns copy of device path
  *
  * RETURNS:
  *    >= 0 file descriptor of matching volume
@@ -100,6 +155,9 @@ int open_by_label(uuid_t uuid, int is_label, int is_log, char *dev)
 	DIR *vg_dir;
 	struct dirent *vg_ent;
 
+	/*
+	 * Check for EVMS Release 1 volumes
+	 */
 	part_fd = fopen("/proc/evms/volumes", "r");
 	if (part_fd) {
 		/* evms/volumes should be complete.  If it exists, don't
@@ -124,6 +182,17 @@ int open_by_label(uuid_t uuid, int is_label, int is_log, char *dev)
 		return (-ENOENT);
 	}
 
+	/*
+	 * Check for evms release 2 volumes
+	 */
+	strcpy(device, "/dev/evms");
+	fd = walk_dir(device, uuid, is_label, is_log);
+	if (fd >= 0) {
+		if (dev)
+			strcpy(dev, device);
+		return fd;
+	}
+
 	/* No evms.  Check /proc/partitions */
 	part_fd = fopen("/proc/partitions", "r");
 	if (part_fd) {
