@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000
+ *   Copyright (c) International Business Machines Corp., 2000-2002
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -14,21 +14,12 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program;  if not, write to the Free Software 
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- *
- *   MODULE_NAME:		inodemap.h
- *
- *   COMPONENT_NAME: 	jfsformat
- *
- *   FUNCTIONS: 	none
- *
  */
-
 #ifndef H_INODEMAP
 #define H_INODEMAP
 
 #include "devices.h"
 
-int32_t init_inode_map(int32_t, HFILE, int64_t, int32_t, int64_t, int32_t, uint16_t, int32_t, uint32_t);
+int init_inode_map(int, HFILE, int64_t, int, int64_t, int, unsigned short, int, unsigned);
 
 #endif
