@@ -566,8 +566,8 @@ static int Bad_Device(HFILE Device_Handle)
 	if (rc)
 		return -1;
 
-	/* Do we have a block special device? */
-	if (!S_ISBLK(stat_data.st_mode))
+	/* Do we have a block special device or regular file? */
+	if (!S_ISBLK(stat_data.st_mode) && !S_ISREG(stat_data.st_mode))
 		return -1;
 
 	return 0;
@@ -692,7 +692,7 @@ int main(int argc, char *argv[])
 	char *device_name = NULL;
 	char *argp;
 	int rc = 0;
-	char volume_label[16] = { "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" };
+        char volume_label[16] = { "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" };
 	int64_t number_of_bytes = 0, bytes_on_device;
 	int64_t number_of_blocks, logloc = 0, logsize_in_bytes = 0;
 	char logdev[255] = { '\0' };	/* Need to use a macro for this size */
@@ -813,8 +813,9 @@ int main(int argc, char *argv[])
 			message_user(MSG_OSO_CANT_FIND_DRIVE, NULL, 0, OSO_MSG);
 			return EINVAL;
 		}
-		/* Do we have a block special device? */
-		if (!S_ISBLK(stat_data.st_mode)) {
+		/* Do we have a block special device or regular file? */
+		if (!S_ISBLK(stat_data.st_mode) && !S_ISREG(stat_data.st_mode))
+		{
 			msg_parms[0] = device_name;
 			message_user(MSG_OSO_NOT_VALID_BLOCK_DEVICE,
 				     msg_parms, 1, OSO_MSG);
