@@ -45,8 +45,8 @@
 #define L0FACTOR	(LPERCTL + 1)
 #define L1FACTOR	((L0FACTOR * LPERCTL) + 1)
 #define L1PAGE(l1)	(2 + ((l1) * L1FACTOR))
-#define L0PAGE(l1, l0)	(L1PAGE(l1) + 1 + (l0 * L0FACTOR))
-#define DMAPPAGE(l1, l0, d)	(L0PAGE(l1, l0) + 1 + d)
+#define L0PAGE(l1, l0)	(L1PAGE(l1) + 1 + ((l0) * L0FACTOR))
+#define DMAPPAGE(l1, l0, d)	(L0PAGE(l1, l0) + 1 + (d))
 
 /* forward references */
 int decode_pagenum(int64_t page, int *l1, int *l0, int *dmap);
@@ -488,9 +488,9 @@ int display_leaf(struct dinode * bmap_inode, int64_t * lblock)
 	int field;
 	int rc;
 	char *token;
-	int dmap, l0, l1, type;
+	int dmap, l0, l1;
 
-	type = decode_pagenum(*lblock, &l1, &l0, &dmap);
+	decode_pagenum(*lblock, &l1, &l0, &dmap);
 
 	if (ujfs_rwdaddr(fd, &address, bmap_inode, (*lblock) << dmap_l2bpp,
 			 GET, bsize) || xRead(address, sizeof (struct dmap), (char *) &d_map)) {
